@@ -1,9 +1,10 @@
-`data.sheet` <-
-function(x){
+### data.sheet.R
+
+data.sheet <- function(x){
   ## Coerces a list with vectors of different length into a data.frame
   ## fills the shorter vectors with NA
   ##
-  ## Authors: Thomas Unternaehrer, Ren Locher
+  ## Authors: Thomas Unternaehrer, Rene Locher
   ## Version 29.09.05
   if (!is.list(x)) stop("'x' must be of type list\n")
   if (min(sapply(x,length)) == 0)
@@ -11,4 +12,3 @@ function(x){
   len <- max(sapply(x,length))
   return(sapply(x, function(y) {length(y) <- len;y}))
 } ## data.sheet
-
